#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://freefr.dl.sourceforge.net/sourceforge/wicd/wicd-1.7.0.tar.bz2
# last revised     : 18.01.2010

softname='wicd'
softversion='1.7.0'
packageversion='64.1'

arch='i686'
cpu='i686'

prefix=/usr

#
# log
#
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://freefr.dl.sourceforge.net/sourceforge/wicd/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion
mkdir -p $dest/etc/rc.d/

# Slack-desc
cat <<EOF > $dest/install/slack-desc
    |-----handy-ruler------------------------------------------------------|
wicd: wicd - A complete network connection manager
wicd:
wicd: wicd supports wired and wireless networks, and capable of creating and
wicd: tracking profiles for both.  It has a template-based wireless
wicd: encryption system, which allows the user to easily add encryption
wicd: methods used.  It ships with some common encryption types, such as WPA
wicd: and WEP. Wicd will automatically connect at startup to any preferred
wicd: network within range.
wicd:
wicd:
wicd:
EOF

#
# check if source is present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    python setup.py configure --no-install-init --no-install-acpi --no-install-kde
	python setup.py install --root=$dest
    
# add 'default' files
 
mkdir -p $dest/usr/doc/$softname-$softversion/html
cp -a \
  AUTHORS INSTALL NEWS README \
      $dest/usr/doc/$softname-$softversion
rm -rf $dest/usr/doc/html

# This sets dhcpcd as the default dhcp client in the Preferences dialog

cat << EOF > $dest/etc/wicd/manager-settings.conf.new
[Settings]
dhcp_client = 2
sudo_app = 0
EOF

# Don't clobber dbus config on upgrade
mv $dest/etc/dbus-1/system.d/wicd.conf $dest/etc/dbus-1/system.d/wicd.conf.new
cp $buildir/rc.wicd $dest/etc/rc.d/rc.wicd.new


#----------------- Compress the man pages

( cd $dest/usr/man || exit 1
  find . -type f -exec gzip -9 {} \;
  for i in $(find . -type l) ; do ln -s $(readlink $i).gz $i.gz ; rm $i ; done
)

mkdir -p $dest/etc/rc.d/desc.d
cat $buildir/wicd.txt > $dest/etc/rc.d/desc.d/wicd.txt

rm $dest/usr/share/applications/wicd.desktop
cat << EOF > $dest/usr/share/applications/wicd.desktop
[Desktop Entry]
Categories=Application;System;X-Zenpanel;
Encoding=UTF-8
Exec=wicd-gtk --no-tray
Icon=wicd-gtk
Name=Network Manager
Name[de]=Netzwerk-Manager
Name[el]=Διαχειριστής συνδέσεων δικτύου
Name[es]=Configuración de Red
Name[fr]=Gestionnaire de connexions
Name[it]=Gestore della rete
Name[nl]=Netwerkbeheer
Name[pt]=Configuração de Rede
Name[pt_BR]=Gerenciador de Rede
Name[sv]=Nätverkshanteraren
Name[tr]=Ağ Yöneticisi
Terminal=false
Type=Application
Version=1.0
EOF

cat << 'DOINST' > $dest/install/doinst.sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.wicd.new:
if [ -e etc/rc.d/rc.wicd ]; then
  cp -a etc/rc.d/rc.wicd etc/rc.d/rc.wicd.new.incoming
  cat etc/rc.d/rc.wicd.new > etc/rc.d/rc.wicd.new.incoming
  mv etc/rc.d/rc.wicd.new.incoming etc/rc.d/rc.wicd.new
fi

# Update desktop menu
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

# Update icon cache if one exists
if [ -r usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache -t -f usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

config etc/dbus-1/system.d/wicd.conf.new
config etc/rc.d/rc.wicd.new
config etc/wicd/manager-settings.conf.new
DOINST

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp $buildir/rc.wicd $dest/$prefix/src/$softname-$softversion

# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

#dep file
echo -e "libglade,net-tools,pycairo,pygobject,pygtk,python,\
wireless-tools,wpa-supplicant,xorg-server,libxcb" > $package.dep

#
# erase source
#
rm -rf $src
rm -rf $dest

#
# generate source file
#
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/xap/wicd/source/build-wicd.sh > $package.src
echo $source >>$package.src

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
